/*
 * Codepage definitions for libbfoverlay
 *
 * Copyright (C) 2020-2024, Joachim Metz <joachim.metz@gmail.com>
 *
 * Refer to AUTHORS for acknowledgements.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#if !defined( _LIBBFOVERLAY_CODEPAGE_H )
#define _LIBBFOVERLAY_CODEPAGE_H

#include <libbfoverlay/types.h>

#if defined( __cplusplus )
extern "C" {
#endif

/* The codepage definitions
 */
enum LIBBFOVERLAY_CODEPAGES
{
	LIBBFOVERLAY_CODEPAGE_ASCII				= 20127,

	LIBBFOVERLAY_CODEPAGE_ISO_8859_1			= 28591,
	LIBBFOVERLAY_CODEPAGE_ISO_8859_2			= 28592,
	LIBBFOVERLAY_CODEPAGE_ISO_8859_3			= 28593,
	LIBBFOVERLAY_CODEPAGE_ISO_8859_4			= 28594,
	LIBBFOVERLAY_CODEPAGE_ISO_8859_5			= 28595,
	LIBBFOVERLAY_CODEPAGE_ISO_8859_6			= 28596,
	LIBBFOVERLAY_CODEPAGE_ISO_8859_7			= 28597,
	LIBBFOVERLAY_CODEPAGE_ISO_8859_8			= 28598,
	LIBBFOVERLAY_CODEPAGE_ISO_8859_9			= 28599,
	LIBBFOVERLAY_CODEPAGE_ISO_8859_10			= 28600,
	LIBBFOVERLAY_CODEPAGE_ISO_8859_11			= 28601,
	LIBBFOVERLAY_CODEPAGE_ISO_8859_13			= 28603,
	LIBBFOVERLAY_CODEPAGE_ISO_8859_14			= 28604,
	LIBBFOVERLAY_CODEPAGE_ISO_8859_15			= 28605,
	LIBBFOVERLAY_CODEPAGE_ISO_8859_16			= 28606,

	LIBBFOVERLAY_CODEPAGE_KOI8_R				= 20866,
	LIBBFOVERLAY_CODEPAGE_KOI8_U				= 21866,

	LIBBFOVERLAY_CODEPAGE_WINDOWS_874			= 874,
	LIBBFOVERLAY_CODEPAGE_WINDOWS_932			= 932,
	LIBBFOVERLAY_CODEPAGE_WINDOWS_936			= 936,
	LIBBFOVERLAY_CODEPAGE_WINDOWS_949			= 949,
	LIBBFOVERLAY_CODEPAGE_WINDOWS_950			= 950,
	LIBBFOVERLAY_CODEPAGE_WINDOWS_1250			= 1250,
	LIBBFOVERLAY_CODEPAGE_WINDOWS_1251			= 1251,
	LIBBFOVERLAY_CODEPAGE_WINDOWS_1252			= 1252,
	LIBBFOVERLAY_CODEPAGE_WINDOWS_1253			= 1253,
	LIBBFOVERLAY_CODEPAGE_WINDOWS_1254			= 1254,
	LIBBFOVERLAY_CODEPAGE_WINDOWS_1255			= 1255,
	LIBBFOVERLAY_CODEPAGE_WINDOWS_1256			= 1256,
	LIBBFOVERLAY_CODEPAGE_WINDOWS_1257			= 1257,
	LIBBFOVERLAY_CODEPAGE_WINDOWS_1258			= 1258
};

#define LIBBFOVERLAY_CODEPAGE_US_ASCII				LIBBFOVERLAY_CODEPAGE_ASCII

#define LIBBFOVERLAY_CODEPAGE_ISO_WESTERN_EUROPEAN		LIBBFOVERLAY_CODEPAGE_ISO_8859_1
#define LIBBFOVERLAY_CODEPAGE_ISO_CENTRAL_EUROPEAN		LIBBFOVERLAY_CODEPAGE_ISO_8859_2
#define LIBBFOVERLAY_CODEPAGE_ISO_SOUTH_EUROPEAN		LIBBFOVERLAY_CODEPAGE_ISO_8859_3
#define LIBBFOVERLAY_CODEPAGE_ISO_NORTH_EUROPEAN		LIBBFOVERLAY_CODEPAGE_ISO_8859_4
#define LIBBFOVERLAY_CODEPAGE_ISO_CYRILLIC			LIBBFOVERLAY_CODEPAGE_ISO_8859_5
#define LIBBFOVERLAY_CODEPAGE_ISO_ARABIC			LIBBFOVERLAY_CODEPAGE_ISO_8859_6
#define LIBBFOVERLAY_CODEPAGE_ISO_GREEK				LIBBFOVERLAY_CODEPAGE_ISO_8859_7
#define LIBBFOVERLAY_CODEPAGE_ISO_HEBREW			LIBBFOVERLAY_CODEPAGE_ISO_8859_8
#define LIBBFOVERLAY_CODEPAGE_ISO_TURKISH			LIBBFOVERLAY_CODEPAGE_ISO_8859_9
#define LIBBFOVERLAY_CODEPAGE_ISO_NORDIC			LIBBFOVERLAY_CODEPAGE_ISO_8859_10
#define LIBBFOVERLAY_CODEPAGE_ISO_THAI				LIBBFOVERLAY_CODEPAGE_ISO_8859_11
#define LIBBFOVERLAY_CODEPAGE_ISO_BALTIC			LIBBFOVERLAY_CODEPAGE_ISO_8859_13
#define LIBBFOVERLAY_CODEPAGE_ISO_CELTIC			LIBBFOVERLAY_CODEPAGE_ISO_8859_14

#define LIBBFOVERLAY_CODEPAGE_ISO_LATIN_1			LIBBFOVERLAY_CODEPAGE_ISO_8859_1
#define LIBBFOVERLAY_CODEPAGE_ISO_LATIN_2			LIBBFOVERLAY_CODEPAGE_ISO_8859_2
#define LIBBFOVERLAY_CODEPAGE_ISO_LATIN_3			LIBBFOVERLAY_CODEPAGE_ISO_8859_3
#define LIBBFOVERLAY_CODEPAGE_ISO_LATIN_4			LIBBFOVERLAY_CODEPAGE_ISO_8859_4
#define LIBBFOVERLAY_CODEPAGE_ISO_LATIN_5			LIBBFOVERLAY_CODEPAGE_ISO_8859_9
#define LIBBFOVERLAY_CODEPAGE_ISO_LATIN_6			LIBBFOVERLAY_CODEPAGE_ISO_8859_10
#define LIBBFOVERLAY_CODEPAGE_ISO_LATIN_7			LIBBFOVERLAY_CODEPAGE_ISO_8859_13
#define LIBBFOVERLAY_CODEPAGE_ISO_LATIN_8			LIBBFOVERLAY_CODEPAGE_ISO_8859_14
#define LIBBFOVERLAY_CODEPAGE_ISO_LATIN_9			LIBBFOVERLAY_CODEPAGE_ISO_8859_15
#define LIBBFOVERLAY_CODEPAGE_ISO_LATIN_10			LIBBFOVERLAY_CODEPAGE_ISO_8859_16

#define LIBBFOVERLAY_CODEPAGE_KOI8_RUSSIAN			LIBBFOVERLAY_CODEPAGE_KOI8_R
#define LIBBFOVERLAY_CODEPAGE_KOI8_UKRAINIAN			LIBBFOVERLAY_CODEPAGE_KOI8_U

#define LIBBFOVERLAY_CODEPAGE_WINDOWS_THAI			LIBBFOVERLAY_CODEPAGE_WINDOWS_874
#define LIBBFOVERLAY_CODEPAGE_WINDOWS_JAPANESE			LIBBFOVERLAY_CODEPAGE_WINDOWS_932
#define LIBBFOVERLAY_CODEPAGE_WINDOWS_CHINESE_SIMPLIFIED	LIBBFOVERLAY_CODEPAGE_WINDOWS_936
#define LIBBFOVERLAY_CODEPAGE_WINDOWS_KOREAN			LIBBFOVERLAY_CODEPAGE_WINDOWS_949
#define LIBBFOVERLAY_CODEPAGE_WINDOWS_CHINESE_TRADITIONAL	LIBBFOVERLAY_CODEPAGE_WINDOWS_950
#define LIBBFOVERLAY_CODEPAGE_WINDOWS_CENTRAL_EUROPEAN		LIBBFOVERLAY_CODEPAGE_WINDOWS_1250
#define LIBBFOVERLAY_CODEPAGE_WINDOWS_CYRILLIC			LIBBFOVERLAY_CODEPAGE_WINDOWS_1251
#define LIBBFOVERLAY_CODEPAGE_WINDOWS_WESTERN_EUROPEAN		LIBBFOVERLAY_CODEPAGE_WINDOWS_1252
#define LIBBFOVERLAY_CODEPAGE_WINDOWS_GREEK			LIBBFOVERLAY_CODEPAGE_WINDOWS_1253
#define LIBBFOVERLAY_CODEPAGE_WINDOWS_TURKISH			LIBBFOVERLAY_CODEPAGE_WINDOWS_1254
#define LIBBFOVERLAY_CODEPAGE_WINDOWS_HEBREW			LIBBFOVERLAY_CODEPAGE_WINDOWS_1255
#define LIBBFOVERLAY_CODEPAGE_WINDOWS_ARABIC			LIBBFOVERLAY_CODEPAGE_WINDOWS_1256
#define LIBBFOVERLAY_CODEPAGE_WINDOWS_BALTIC			LIBBFOVERLAY_CODEPAGE_WINDOWS_1257
#define LIBBFOVERLAY_CODEPAGE_WINDOWS_VIETNAMESE		LIBBFOVERLAY_CODEPAGE_WINDOWS_1258

#if defined( __cplusplus )
}
#endif

#endif /* !defined( _LIBBFOVERLAY_CODEPAGE_H ) */

